Module rates

Module rates 

Structs

InstantiateMsg
PaymentAttribute
An attribute struct used for any events that involve a payment
PaymentsResponse
PercentRate
RateInfo

Enums

ExecuteMsg
QueryMsg
Rate
An enum used to define various types of fees

Functions

calculate_fee
Calculates a fee amount given a Rate and payment amount.