Rate

Enum Rate 

pub enum Rate {
    Flat(Coin),
    Percent(PercentRate),
}
An enum used to define various types of fees

Variants



Flat(Coin)

A flat rate fee



Percent(PercentRate)

A percentage fee

Implementations

Source

impl Rate

pub fn is_non_zero(&self) -> Result<bool, ContractError>

Validates that a given rate is non-zero. It is expected that the Rate is not an External Rate.

pub fn validate( &self, querier: &QuerierWrapper<'_>, ) -> Result<Rate, ContractError>

Validates self and returns an “unwrapped” version of itself wherein if it is an External Rate, the actual rate value is retrieved from the Primitive Contract.