pub enum Rate {
Flat(Coin),
Percent(PercentRate),
}Expand description
An enum used to define various types of fees
Variants
Implementations
Sourceimpl Rate
impl Rate
Sourcepub fn is_non_zero(&self) -> Result<bool, ContractError>
pub fn is_non_zero(&self) -> Result<bool, ContractError>
Validates that a given rate is non-zero. It is expected that the Rate is not an External Rate.
Sourcepub fn validate(
&self,
querier: &QuerierWrapper<'_>,
) -> Result<Rate, ContractError>
pub fn validate( &self, querier: &QuerierWrapper<'_>, ) -> Result<Rate, ContractError>
Validates self and returns an “unwrapped” version of itself wherein if it is an External
Rate, the actual rate value is retrieved from the Primitive Contract.